
from .landslide_probability import LandslideProbability


__all__ = ["LandslideProbability"]
